@@ -1,6 +1,7 @@
 from typing import TYPE_CHECKING
 
 import datetime
+from enum import Enum
 
 from hoss.api import CoreAPI
 from hoss.ref import DatasetRef
@@ -14,14 +15,23 @@ PERM_READ = "r"
 PERM_READ_WRITE = "rw"
 
 
+class DeleteStatus(Enum):
+    NOT_SCHEDULED = "NOT_SCHEDULED"
+    SCHEDULED = "SCHEDULED"
+    IN_PROGRESS = "IN_PROGRESS"
+    ERROR = "ERROR"
+
+
 class Dataset(CoreAPI, DatasetRef):
     def __init__(self, namespace: 'Namespace', dataset_name: str, description: str,
-                 created_on: datetime.datetime,
+                 created_on: datetime.datetime, delete_on: datetime.datetime, delete_status: DeleteStatus,
                  root_directory: str, owner: str, bucket: str, permissions: dict) -> None:
         self.namespace = namespace
         self.dataset_name = dataset_name
         self.description = description
         self.created_on = created_on
+        self.delete_on = delete_on
+        self.delete_status = delete_status
         self.root_directory = root_directory
         self.owner = owner
         self.bucket = bucket
@@ -122,3 +132,54 @@ class Dataset(CoreAPI, DatasetRef):
             self._request("PUT", f"/namespace/{self.namespace.name}/dataset/{self.dataset_name}/group/{group_name}/access/{permission}")
             self.permissions[group_name] = permission
         return self
+    
+    def suggest_keys(self, prefix, limit=None):
+        """Get suggestions for keys based on existing metadata.
+        
+        Args:
+            prefix: substring that will be autocompleted to get suggestions
+            limit: number of documents to return suggestions (due to duplicate results in multiple documents
+                the actual number of suggestions could be lower than the limit, and due to multiple matching
+                keys in a single document the number of suggestions could be higher than the limit)
+        
+        Returns:
+            A list of suggested keys
+        """
+
+        # construct query parameters
+        query_params = [f"prefix={prefix}"]
+        if limit:
+            query_params.append(f"limit={limit}")
+        query_param_str = "&".join(query_params)
+
+        # make request
+        url = f"/search/namespace/{self.namespace.name}/dataset/{self.dataset_name}/key?{query_param_str}"
+        response = self._request("GET", url)
+
+        return response["keys"]
+
+    def suggest_values(self, key, prefix, limit=None):
+        """Get suggestions for values for a given key based on existing metadata.
+        
+        Args:
+            key: the key for which to return suggested values
+            prefix: substring that will be autocompleted to get suggestions
+            limit: number of documents to return suggestions (due to duplicate results in multiple documents
+                the actual number of suggestions could be lower than the limit, and due to multiple matching
+                keys in a single document the number of suggestions could be higher than the limit)
+        
+        Returns:
+            A list of suggested values
+        """
+
+        # construct query parameters
+        query_params = [f"prefix={prefix}"]
+        if limit:
+            query_params.append(f"limit={limit}")
+        query_param_str = "&".join(query_params)
+
+        # make request
+        url = f"/search/namespace/{self.namespace.name}/dataset/{self.dataset_name}/key/{key}/value?{query_param_str}"
+        response = self._request("GET", url)
+
+        return response["values"]
